"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
/** @internal */
class LoggerHelper {
    static cleanUpFilePath(fileName) {
        if (fileName == null) {
            return fileName;
        }
        return Object.entries(fileName.split(path_1.sep)).reduce((cleanFileName, fileNamePart) => fileNamePart[1] !== LoggerHelper.cwdArray[fileNamePart[0]]
            ? (cleanFileName += path_1.sep + fileNamePart[1])
            : cleanFileName, "");
    }
    static getCallSites(error) {
        const _prepareStackTrace = Error.prepareStackTrace;
        Error.prepareStackTrace = (_, stack) => stack;
        const stack = error == null
            ? new Error().stack.slice(1)
            : error.stack;
        Error.prepareStackTrace = _prepareStackTrace;
        return stack;
    }
    static toStackFrameObject(stackFrame) {
        var _a, _b;
        const filePath = stackFrame.getFileName();
        return {
            filePath: (_a = LoggerHelper.cleanUpFilePath(filePath)) !== null && _a !== void 0 ? _a : "",
            fullFilePath: filePath !== null && filePath !== void 0 ? filePath : "",
            fileName: path_1.basename((_b = stackFrame.getFileName()) !== null && _b !== void 0 ? _b : ""),
            lineNumber: stackFrame.getLineNumber(),
            columnNumber: stackFrame.getColumnNumber(),
            isConstructor: stackFrame.isConstructor(),
            functionName: stackFrame.getFunctionName(),
            typeName: stackFrame.getTypeName(),
            methodName: stackFrame.getMethodName(),
        };
    }
    static errorToJsonHelper() {
        if (!("toJSON" in Error.prototype))
            /* eslint-disable */
            Object.defineProperty(Error.prototype, "toJSON", {
                /* eslint-enable */
                value: function () {
                    return Object.getOwnPropertyNames(this).reduce((alt, key) => {
                        alt[key] = this[key];
                        return alt;
                    }, {});
                },
                configurable: true,
                writable: true,
            });
    }
    static overwriteConsole($this, handleLog) {
        ["log", "debug", "info", "warn", "trace", "error"].forEach((name) => {
            console[name] = (...args) => {
                const loglevelMapping = {
                    log: 0,
                    trace: 1,
                    debug: 2,
                    info: 3,
                    warn: 4,
                    error: 5,
                };
                return handleLog.apply($this, [
                    loglevelMapping[name.toLowerCase()],
                    args,
                ]);
            };
        });
    }
    static colorizeJson(json, chalk, colors) {
        const chalkColors = {
            number: chalk.hex(colors.number),
            key: chalk.hex(colors.key),
            string: chalk.hex(colors.string),
            boolean: chalk.hex(colors.boolean),
            null: chalk.hex(colors.null),
        };
        if (typeof json !== "string") {
            json = JSON.stringify(json, undefined, 2);
        }
        return json.replace(/("(\\u[a-zA-Z0-9]{4}|\\[^u]|[^\\"])*"(\s*:)?|\b(true|false|null)\b|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?)/g, function (match) {
            let cls = "number";
            if (/^"/.test(match)) {
                if (/:$/.test(match)) {
                    cls = "key";
                }
                else {
                    cls = "string";
                }
            }
            else if (/true|false/.test(match)) {
                cls = "boolean";
            }
            else if (/null/.test(match)) {
                cls = "null";
            }
            return chalkColors[cls](match);
        });
    }
}
exports.LoggerHelper = LoggerHelper;
LoggerHelper.cwdArray = process.cwd().split(path_1.sep);
//# sourceMappingURL=LoggerHelper.js.map