import { IErrorObject, ILogObject, ISettings, ISettingsParam, IStd, ITransportLogger, TLogLevel } from "./interfaces";
export { ITransportLogger, ILogObject, IErrorObject, ISettingsParam, TLogLevel, IStd, };
/**
 * 📝 Expressive TypeScript Logger for Node.js
 * @public
 */
export declare class Logger {
    private readonly _logLevels;
    private _ignoreStackLevels;
    private _attachedTransports;
    private readonly _minLevelToStdErr;
    readonly settings: ISettings;
    /**
     *
     * @param settings Configuration of the logger instance  (all settings are optional with sane defaults)
     */
    constructor(settings?: ISettingsParam);
    /**
     *  Attaches external Loggers, e.g. external log services, file system, database
     *
     * @param transportLogger External logger to be attached. Must implement all log methods.
     * @param minLevel        Minimum log level to be forwarded to this attached transport logger.
     */
    attachTransport(transportLogger: ITransportLogger<(message: ILogObject) => void>, minLevel?: TLogLevel): void;
    /**
     * Logs a silly message.
     * @param args  Multiple log attributes that should be logged out.
     */
    silly(...args: unknown[]): ILogObject;
    /**
     * Logs a trace message.
     * @param args  Multiple log attributes that should be logged out.
     */
    trace(...args: unknown[]): ILogObject;
    /**
     * Logs a debug message.
     * @param args  Multiple log attributes that should be logged out.
     */
    debug(...args: unknown[]): ILogObject;
    /**
     * Logs an info message.
     * @param args  Multiple log attributes that should be logged out.
     */
    info(...args: unknown[]): ILogObject;
    /**
     * Logs a warn message.
     * @param args  Multiple log attributes that should be logged out.
     */
    warn(...args: unknown[]): ILogObject;
    /**
     * Logs an error message.
     * @param args  Multiple log attributes that should be logged out.
     */
    error(...args: unknown[]): ILogObject;
    /**
     * Logs a fatal message.
     * @param args  Multiple log attributes that should be logged out.
     */
    fatal(...args: unknown[]): ILogObject;
    private _handleLog;
    private _buildLogObject;
    private _toStackObjectArray;
    private _printPrettyLog;
    private _printPrettyStack;
    private _printJsonLog;
}
//# sourceMappingURL=index.d.ts.map